/**********************************************************************
 *   PRODUCT:   SAS
 *   VERSION:   9.1
 *   NAME:      %mdumap
 *   DATE:      14Jan2004
 *   DESC:      Metadata User Extract XML maps and queries - Build XML
 *              queries and their corresponding XML maps in
 *              temporary files.  These queries and maps are used to
 *              extract user and group metadata from a metadata repository
 *              This macro is used primarily by the mduextr macro.
 *
 *   TEMPLATE SOURCE:  (None Specified.)
 *   UPDATED:   Version 9.2   19Jul2006

 ***********************************************************************/

/*---------------------------------------------------------------------------
 *
 *   This macro will assign a temporary fileref to a filename specified
 *   as a parameter and then write an xml map to it.  The map written is
 *   specified as a parameter.
 *
 *   Parameters
 *       mapname = Should be one of the following:
 *                   USERINFO
 *                   GROUPINFO
 *                   GROUPMEMINFO*
 *       mapref = name of the fileref that should be assigned to the temporary
 *                 xml map file that is created.
 *     queryref = name of the fileref that should be assigned to the
 *                 temporary file that will contain the query that is used
 *                 with the map.
 *
 *    Notes:
 *        *The GROUPMEMINFO map does not return a query fileref.  The query
 *         for this map is currently generated dynamically by the caller.
 *         Note though that a querymap= parameter must be specified to get
 *         thru the error checking of this code.  However, the file created
 *         will be empty.
 *
 *---------------------------------------------------------------------------*/


%macro mdumap(mapname=, mapref=, queryref=);

%if ("&mapref" = "")  %then %do;
  %put ERROR:  No XML MAP fileref specified.  Map not created.;
  %return;
  %end;

%if ("&queryref" = "")  %then %do;
  %put ERROR:  No query fileref specified.  Map not created.;
  %return;
  %end;


/* Set host-specific recfm macro variable value for TEMP files
*  (so we are "good citizen" on both OS390 and directory-based hosts)
*/
%if %superq(SYSSCPL) eq %str(z/OS) or %superq(SYSSCPL) eq %str(OS/390) %then
    %let recfm=recfm=vb;
%else
    %let recfm=;


/* assign the fileref to a temporary file */
filename &mapref temp lrecl=256 encoding="UTF-8" &recfm;
filename &queryref temp lrecl=256 &recfm;



/**************************************************
*
*
*  User Info map
*
*
***************************************************/
%if ("&mapname" = "USERINFO") %then %do;

/*------------------------
* Build the Query - do not request password
*------------------------*/
data _null_;
   file &queryref;
put '<GetMetadataObjects>';
put '    <Reposid>$METAREPOSITORY</Reposid>';
put '    <Type>Person</Type>';
put '    <Objects/>';
put '    <NS>SAS</NS>';
put '    <Flags>388</Flags>  <!-- OMI_XMLSELECT(128) + OMI_GET_METADATA(256) ';
put '                           + OMI_TEMPLATE(4) -->';
put '    <Options>';
put '        <Templates>';
put '            <Person Id="" Name="" Desc="" title="" DisplayName="">';
put '                <ExternalIdentities />';
put '                <Logins /> ';
put '                <EmailAddresses />';
put '                <Locations />';
put '                <PhoneNumbers />';
put '            </Person>    ';
put '            <ExternalIdentity  Context="" Identifier="" /> ';
put '            <Login Id="" Name="" Desc="" UserId="" >';
put '                <Domain /> ';
put '            </Login>';
put '            <Email Id="" Name="" Desc="" Address="" EmailType=""/>';
put '            <Location Id="" Name="" Desc="" Address="" Area=""';
put '                      City="" Country="" PostCode="" LocationType="" />';
put '            <Phone Id="" Name="" Desc="" Number="" PhoneType="" />';
put '            <AuthenticationDomain Id="" Name="" >';
put '                <ExternalIdentities />';
put '            </AuthenticationDomain>';
put '   ';
put '        </Templates>';
put '    </Options>';
put '</GetMetadataObjects>';
run;


/*------------------------
* Build the Map
*------------------------*/
data _null_;
   file &mapref encoding="UTF-8";
put '<?xml version="1.0" encoding="UTF-8" ?>';
put ' ';
put '<SXLEMAP version="1.2" name="UserInfoMap">';
put '  ';
put '  <!-- ############################################################ -->';
put '  <TABLE name="Person">';
put '    <TABLE-PATH syntax="XPath">/GetMetadataObjects/Objects/Person</TABLE-PATH>';
put '  ';
put '    <COLUMN name="Id">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Name">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/@Name</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>60</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Desc">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/@Desc</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>200</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Title">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/@Title</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>200</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="DisplayName">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/@DisplayName</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>256</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="ExtId_Id">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/ExternalIdentities/ExternalIdentity/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="ExtId_Context">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/ExternalIdentities/ExternalIdentity/@Context</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>200</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="ExtId_Identifier">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/ExternalIdentities/ExternalIdentity/@Identifier</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>200</LENGTH>';
put '    </COLUMN>';
put '  ';
put '  </TABLE>';
put '  ';
put '  <!-- ############################################################ -->';
put '  <TABLE name="Login">';
put '    <TABLE-PATH syntax="XPath">/GetMetadataObjects/Objects/Person/Logins/Login</TABLE-PATH>';
put '  ';
put '    <COLUMN name="Id">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Logins/Login/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Name">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Logins/Login/@Name</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>60</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Desc">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Logins/Login/@Desc</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>200</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="UserID">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Logins/Login/@UserID</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>128</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Password">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Logins/Login/@Password</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>64</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Person_Id" retain="YES">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="AuthDom_Id">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Logins/Login/Domain/AuthenticationDomain/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="AuthDom_Name">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Logins/Login/Domain/AuthenticationDomain/@Name</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>60</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="AuthDom_ExtId_Context">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Logins/Login/Domain/AuthenticationDomain/ExternalIdentities/ExternalIdentity/@Context</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>60</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="AuthDom_ExtId_Identifier">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Logins/Login/Domain/AuthenticationDomain/ExternalIdentities/ExternalIdentity/@Identifier</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>128</LENGTH>';
put '    </COLUMN>';
put '  ';
put '  </TABLE>';
put '  ';
put '  <!-- ############################################################ -->';
put '  <TABLE name="Email">';
put '    <TABLE-PATH syntax="XPath">/GetMetadataObjects/Objects/Person/EmailAddresses/Email</TABLE-PATH>';
put '  ';
put '    <COLUMN name="Id">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/EmailAddresses/Email/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Name">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/EmailAddresses/Email/@Name</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>60</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Desc">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/EmailAddresses/Email/@Desc</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>200</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Address">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/EmailAddresses/Email/@Address</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>256</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="EmailType">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/EmailAddresses/Email/@EmailType</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>32</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Person_Id" retain="YES">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '  </TABLE>';
put '  ';
put '  <!-- ############################################################ -->';
put '  <TABLE name="Location">';
put '    <TABLE-PATH syntax="XPath">/GetMetadataObjects/Objects/Person/Locations/Location</TABLE-PATH>';
put '  ';
put '    <COLUMN name="Id">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Locations/Location/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Name">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Locations/Location/@Name</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>60</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Desc">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Locations/Location/@Desc</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>200</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Address">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Locations/Location/@Address</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>256</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Area">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Locations/Location/@Area</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>64</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="City">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Locations/Location/@City</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>64</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="PostCode">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Locations/Location/@PostCode</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>32</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Country">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Locations/Location/@Country</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>64</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="LocationType">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/Locations/Location/@LocationType</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>64</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Person_Id" retain="YES">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '  </TABLE>';
put '  ';
put '  <!-- ############################################################ -->';
put '  <TABLE name="Phone">';
put '    <TABLE-PATH syntax="XPath">/GetMetadataObjects/Objects/Person/PhoneNumbers/Phone</TABLE-PATH>';
put '  ';
put '    <COLUMN name="Id">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/PhoneNumbers/Phone/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Name">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/PhoneNumbers/Phone/@Name</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>60</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Desc">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/PhoneNumbers/Phone/@Desc</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>200</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Number">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/PhoneNumbers/Phone/@Number</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>200</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="PhoneType">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/PhoneNumbers/Phone/@PhoneType</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>32</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Person_Id" retain="YES">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/Person/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '  </TABLE>';
put '  ';
put '</SXLEMAP>';

run;

%return;  /* we're done with user info map */

%end;  /* end of xml map for USERINFO */



/**************************************************
*
*
*  Group Info map
*
*
***************************************************/

%if ("&mapname" = "GROUPINFO") %then %do;
/*------------------------
* Build the Query - do not request password
*------------------------*/
data _null_;
   file &queryref;
put '<GetMetadataObjects>';
put '    <Reposid>$METAREPOSITORY</Reposid>';
put '    <Type>IdentityGroup</Type>';
put '    <Objects/>';
put '    <NS>SAS</NS>';
put '    <Flags>388</Flags>  <!-- OMI_XMLSELECT(128) + OMI_GET_METADATA(256) ';
put '                           + OMI_TEMPLATE(4) -->';
put '    <Options>';
put '        <Templates>';
put '            <IdentityGroup Id="" Name="" Desc="" GroupType="" DisplayName="">';
put '                <ExternalIdentities/>';
put '                <Logins/>';
put '            </IdentityGroup>   ';
put '            <ExternalIdentity  Context="" Identifier="" /> ';
put '            <Login Id="" Name="" Desc="" UserId="" >';
put '                 <Domain /> ';
put '            </Login>';
put '            <AuthenticationDomain Id="" Name="" >';
put '                <ExternalIdentities />';
put '            </AuthenticationDomain>';
put '         </Templates>';
put '      </Options>';
put '      </GetMetadataObjects>';
run;

/*------------------------
* Build the Map
*------------------------*/
data _null_;
   file &mapref encoding="UTF-8";
put '<?xml version="1.0" encoding="UTF-8" ?>';
put '  ';
put '<SXLEMAP version="1.2" name="groupinfo">';
put '  ';
put '  <!-- ############################################################ -->';
put '  <TABLE name="IdentityGroup">';
put '    <TABLE-PATH syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup</TABLE-PATH>';
put '  ';
put '    <COLUMN name="Id">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Name">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/@Name</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>60</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Desc">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/@Desc</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>200</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="GroupType">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/@GroupType</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>40</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="DisplayName">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/@DisplayName</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>256</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="ExtId_Context">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/ExternalIdentities/ExternalIdentity/@Context</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>32</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="ExtId_Identifier">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/ExternalIdentities/ExternalIdentity/@Identifier</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>128</LENGTH>';
put '    </COLUMN>';
put '  ';
put '  </TABLE>';
put '  ';
put '  ';
put '  <!-- ############################################################ -->';
put '  <TABLE name="IdGroupLogins">';
put '    <TABLE-PATH syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/Logins/Login</TABLE-PATH>';
put '  ';
put '    <COLUMN name="Id">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/Logins/Login/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Name">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/Logins/Login/@Name</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>60</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Desc">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/Logins/Login/@Desc</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>200</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="UserID">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/Logins/Login/@UserID</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>128</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Password">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/Logins/Login/@Password</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>64</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="Group_Id" retain="YES">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="AuthDom_Id">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/Logins/Login/Domain/AuthenticationDomain/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="AuthDom_Name">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/Logins/Login/Domain/AuthenticationDomain/@Name</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>60</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="AuthDom_ExtId_Context">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/Logins/Login/Domain/AuthenticationDomain/ExternalIdentities/ExternalIdentity/@Context</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>60</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="AuthDom_ExtId_Identifier">';
put '      <PATH  syntax="XPath">/GetMetadataObjects/Objects/IdentityGroup/Logins/Login/Domain/AuthenticationDomain/ExternalIdentities/ExternalIdentity/@Identifier</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>128</LENGTH>';
put '    </COLUMN>';
put '  ';
put '  </TABLE>';
put '  ';
put '</SXLEMAP>';

run;

%return; /* we're done with group info map */

%end;  /* end of xml map for GROUPINFO */




/**************************************************
*
*
*  Group Member Info map
*
*
***************************************************/

%if ("&mapname" = "GROUPMEMINFO") %then %do;

/*------------------------
* Build the Query
*------------------------*/
   /**** NO QUERY PRODUCED FOR THIS MAP ****/


/*------------------------
* Build the MAP
*------------------------*/

data _null_;
   file &mapref encoding="UTF-8";
put '<?xml version="1.0" encoding="UTF-8" ?>';
put '  ';
put '<SXLEMAP version="1.2" name="groupmems">';
put '  ';
put '  <!-- ############################################################ -->';
put '  <TABLE name="grpmempersons">';
put '    <TABLE-PATH syntax="XPath">/GetMetadata/Metadata/IdentityGroup/MemberIdentities/Person</TABLE-PATH>';
put '  ';
put '    <COLUMN name="Id" retain="YES">';
put '      <PATH  syntax="XPath">/GetMetadata/Metadata/IdentityGroup/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '    ';
put '    <COLUMN name="Name" retain="YES">';
put '       <PATH  syntax="XPath">/GetMetadata/Metadata/IdentityGroup/@Name</PATH>';
put '       <TYPE>character</TYPE>';
put '       <DATATYPE>string</DATATYPE>';
put '       <LENGTH>60</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="memId">';
put '      <PATH  syntax="XPath">/GetMetadata/Metadata/IdentityGroup/MemberIdentities/Person/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="memName">';
put '      <PATH  syntax="XPath">/GetMetadata/Metadata/IdentityGroup/MemberIdentities/Person/@Name</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>60</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="memDesc">';
put '      <PATH  syntax="XPath">/GetMetadata/Metadata/IdentityGroup/MemberIdentities/Person/@Desc</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>200</LENGTH>';
put '    </COLUMN>';
put '  ';
put '  </TABLE>';
put '  ';
put '  <!-- ############################################################ -->';
put '  <TABLE name="grpmemgroups">';
put '    <TABLE-PATH syntax="XPath">/GetMetadata/Metadata/IdentityGroup/MemberIdentities/IdentityGroup</TABLE-PATH>';
put '  ';
put '    <COLUMN name="Id" retain="YES">';
put '      <PATH  syntax="XPath">/GetMetadata/Metadata/IdentityGroup/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '    ';
put '    <COLUMN name="Name" retain="YES">';
put '       <PATH  syntax="XPath">/GetMetadata/Metadata/IdentityGroup/@Name</PATH>';
put '       <TYPE>character</TYPE>';
put '       <DATATYPE>string</DATATYPE>';
put '       <LENGTH>60</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="memId">';
put '      <PATH  syntax="XPath">/GetMetadata/Metadata/IdentityGroup/MemberIdentities/IdentityGroup/@Id</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>17</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="memName">';
put '      <PATH  syntax="XPath">/GetMetadata/Metadata/IdentityGroup/MemberIdentities/IdentityGroup/@Name</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>60</LENGTH>';
put '    </COLUMN>';
put '  ';
put '    <COLUMN name="memDesc">';
put '      <PATH  syntax="XPath">/GetMetadata/Metadata/IdentityGroup/MemberIdentities/IdentityGroup/@Desc</PATH>';
put '      <TYPE>character</TYPE>';
put '      <DATATYPE>string</DATATYPE>';
put '      <LENGTH>200</LENGTH>';
put '    </COLUMN>';
put '  ';
put '  </TABLE>';
put '  ';
put '</SXLEMAP>';


run;

%return; /* we're done with the group member info map. */

%end;  /* end of xml map for GROUPMEMINFO */




%mend mdumap;
